DSEntraIDEventHandler class

Handles Entra ID (Azure AD) authentication events

Constructors

DSEntraIDEventHandler({required dynamic onEvent(String, Map<String, dynamic>)})

Properties

hashCode int
The hash code for this object.
no setterinherited
onEvent → dynamic Function(String, Map<String, dynamic>)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Cleanup
emitEvent(String eventType, Map<String, dynamic> eventData) Future<void>
Emits an authentication event
handleAccountDeprovisioned(String userId) Future<void>
Handles account deletion / deprovisioning
handleAccountProvisioned({required String userId, required String email, String source = 'entra_id'}) Future<void>
Handles user provisioning (enterprise onboarding)
handleAttributeUpdate(String userId, List<String> attributes) Future<void>
Handles attribute updates (claims, roles, groups)
handleConditionalAccessFailure(String userId, String policy) Future<void>
Handles conditional access blocks
handleError({required String operation, required String error, String? aadErrorCode}) Future<void>
Handles generic error events
handleLoginFailure({required String email, required String reason}) Future<void>
Handles login failure
handleLoginSuccess({required String userId, required String email, String authMethod = 'redirect'}) Future<void>
Handles login success
handleLogout(String userId) Future<void>
Handles logout
handleMFAChallenge(String userId, String method) Future<void>
Handles MFA challenge
handlePasswordResetRequested({required String email}) Future<void>
handleSessionEvent(String userId, String action) Future<void>
Handles session lifecycle events
handleSilentAuth(String userId) Future<void>
Handles silent auth / SSO
handleTokenRefresh(String userId) Future<void>
Handles access token refresh
handleUserFlowComplete({required String flowName, required String userId, required String email}) Future<void>
initialize() → void
Initializes the event handler
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited