DSTokenManager class

Constructors

DSTokenManager()

Properties

accessToken → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasValidToken → bool
no setter
refreshToken → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setTokens({required String accessToken, String? refreshToken}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited